enum CartStatus {
  received,
  baking,
  onItsWay,
  delivered
}

class ItemModel {
  String cookie;
  int qty;
  String box;

  ItemModel({
    this.cookie,
    this.qty,
    this.box
});

  factory ItemModel.fromJson(Map<String, dynamic> parsedJson) {
    return ItemModel(
        cookie: parsedJson["cookie"],
        qty: parsedJson["qty"],
        box: parsedJson["box"]
    );
  }
}

class OrderModel {
  String documentID;
  String id;
  String instructions;
  int total;
  String profile;
  bool paid;
  DateTime when;
  int status;
  List<ItemModel> items;

  OrderModel({
    this.documentID,
    this.id,
    this.instructions,
    this.total,
    this.profile,
    this.paid,
    this.when,
    this.status,
    this.items
  });

  factory OrderModel.fromJson(Map<String, dynamic> parsedJson, String documentID) {
    List<dynamic> items = parsedJson["items"];
    return OrderModel(
      documentID: documentID,
      id: parsedJson['id'],
      instructions: parsedJson['instructions'],
      total: parsedJson['total'],
      profile: parsedJson['profile'],
      paid: parsedJson['paid'] ?? false,
      when: parsedJson['when'].toDate(),
      status: parsedJson['status'],
      items: items.map((item) => ItemModel.fromJson(item)).toList()
    );
  }

  static mapStateToString(CartStatus status) {
    switch (status) {
      case CartStatus.received: return "New";
      case CartStatus.baking: return "Baking";
      case CartStatus.onItsWay: return "Delivering";
      case CartStatus.delivered: return "Delivered";
    }
  }

  static priceToString(price) {
    return '\$${(price / 100).toStringAsFixed(2)}';
  }
}